@@ -1,25 +1,24 @@
-use std::{char::decode_utf16, marker::PhantomData, sync::Arc};
+use std::{char::decode_utf16, sync::Arc};
 
-use arrow::{
-    array::{
-        ArrayRef, BinaryBuilder, BooleanBuilder, DecimalBuilder, PrimitiveBuilder, StringBuilder,
-    },
-    datatypes::ArrowPrimitiveType,
-};
+use arrow::array::{ArrayRef, BooleanBuilder, DecimalBuilder, StringBuilder};
 use atoi::FromRadix10Signed;
 use odbc_api::{
     buffers::{AnyColumnView, BufferDescription, BufferKind, Item},
     Bit,
 };
 
+mod binary;
 mod date_time;
+mod no_conversion;
 mod with_conversion;
 
 pub use self::{
+    binary::{Binary, FixedSizedBinary},
     date_time::{
         DateConversion, TimestampMsConversion, TimestampNsConversion, TimestampSecConversion,
         TimestampUsConversion,
     },
+    no_conversion::no_conversion,
     with_conversion::{with_conversion, Conversion},
 };
 
@@ -32,86 +31,6 @@ pub trait ColumnStrategy {
     fn fill_arrow_array(&self, column_view: AnyColumnView) -> ArrayRef;
 }
 
-/// This is applicable thenever there is a Primitive Arrow array whose native type is identical with
-/// the ODBC buffer type.
-pub fn no_conversion<T>(nullable: bool) -> Box<dyn ColumnStrategy>
-where
-    T: ArrowPrimitiveType,
-    T::Native: Item,
-{
-    if nullable {
-        Box::new(NullableDirectStrategy::<T>::new())
-    } else {
-        Box::new(NonNullDirectStrategy::<T>::new())
-    }
-}
-
-struct NonNullDirectStrategy<T> {
-    phantom: PhantomData<T>,
-}
-
-impl<T> NonNullDirectStrategy<T> {
-    fn new() -> Self {
-        Self {
-            phantom: PhantomData,
-        }
-    }
-}
-
-impl<T> ColumnStrategy for NonNullDirectStrategy<T>
-where
-    T: ArrowPrimitiveType,
-    T::Native: Item,
-{
-    fn buffer_description(&self) -> BufferDescription {
-        BufferDescription {
-            kind: T::Native::BUFFER_KIND,
-            nullable: false,
-        }
-    }
-
-    fn fill_arrow_array(&self, column_view: AnyColumnView) -> ArrayRef {
-        let slice = T::Native::as_slice(column_view).unwrap();
-        let mut builder = PrimitiveBuilder::<T>::new(slice.len());
-        builder.append_slice(slice).unwrap();
-        Arc::new(builder.finish())
-    }
-}
-
-struct NullableDirectStrategy<T> {
-    phantom: PhantomData<T>,
-}
-
-impl<T> NullableDirectStrategy<T> {
-    fn new() -> Self {
-        Self {
-            phantom: PhantomData,
-        }
-    }
-}
-
-impl<T> ColumnStrategy for NullableDirectStrategy<T>
-where
-    T: ArrowPrimitiveType,
-    T::Native: Item,
-{
-    fn buffer_description(&self) -> BufferDescription {
-        BufferDescription {
-            kind: T::Native::BUFFER_KIND,
-            nullable: true,
-        }
-    }
-
-    fn fill_arrow_array(&self, column_view: AnyColumnView) -> ArrayRef {
-        let values = T::Native::as_nullable_slice(column_view).unwrap();
-        let mut builder = PrimitiveBuilder::<T>::new(values.len());
-        for value in values {
-            builder.append_option(value.copied()).unwrap();
-        }
-        Arc::new(builder.finish())
-    }
-}
-
 pub struct NonNullableBoolean;
 
 impl ColumnStrategy for NonNullableBoolean {
@@ -257,42 +176,3 @@ impl ColumnStrategy for Decimal {
         }
     }
 }
-
-pub struct Binary {
-    /// Maximum length in bytes of elements
-    max_len: usize,
-    nullable: bool,
-}
-
-impl Binary {
-    pub fn new(nullable: bool, max_len: usize) -> Self {
-        Self { max_len, nullable }
-    }
-}
-
-impl ColumnStrategy for Binary {
-    fn buffer_description(&self) -> BufferDescription {
-        BufferDescription {
-            nullable: self.nullable,
-            kind: BufferKind::Binary {
-                length: self.max_len,
-            },
-        }
-    }
-
-    fn fill_arrow_array(&self, column_view: AnyColumnView) -> ArrayRef {
-        let values = match column_view {
-            AnyColumnView::Binary(values) => values,
-            _ => unreachable!(),
-        };
-        let mut builder = BinaryBuilder::new(values.len());
-        for value in values {
-            if let Some(bytes) = value {
-                builder.append_value(bytes).unwrap();
-            } else {
-                builder.append_null().unwrap();
-            }
-        }
-        Arc::new(builder.finish())
-    }
-}
