@@ -57,7 +57,10 @@ use arrow::{
     error::ArrowError,
     record_batch::{RecordBatch, RecordBatchReader},
 };
-use column_strategy::{ColumnStrategy, DateConversion, TimestampMsConversion, TimestampNsConversion, TimestampSecConversion, TimestampUsConversion, with_conversion};
+use column_strategy::{
+    with_conversion, ColumnStrategy, DateConversion, FixedSizedBinary, TimestampMsConversion,
+    TimestampNsConversion, TimestampSecConversion, TimestampUsConversion,
+};
 use odbc_api::{
     buffers::ColumnarRowSet, ColumnDescription, Cursor, DataType as OdbcDataType, RowSetCursor,
 };
@@ -74,19 +77,22 @@ mod column_strategy;
 pub use arrow;
 pub use odbc_api;
 
+/// A variation of things which can go wrong then creating an [`OdbcReader`].
 #[derive(Error, Debug)]
 pub enum Error {
+    /// The type specified in the arrow schema is not supported to be fetched from the database.
     #[error(
         "Unsupported arrow type: `{0}`. This type can currently not be fetched from an ODBC data \
         source by an instance of OdbcReader."
     )]
-    /// The type specified in the arrow schema is not supported to be fetched from the database.
     UnsupportedArrowType(ArrowDataType),
+    /// At ODBC api calls gaining information about the columns did fail.
     #[error(
         "An error occurred fetching the column description or data type from the metainformation \
         attached to the ODBC result set:\n{0}"
     )]
     FailedToDescribeColumn(#[source] odbc_api::Error),
+    /// Unable to retrieve the column display size for the column.
     #[error(
         "Unable to deduce the maximum string length for the SQL Data Type reported by the ODBC \
         driver. Reported SQL data type is: {:?}.\n Error fetching column display size: {source}",
@@ -96,8 +102,10 @@ pub enum Error {
         sql_type: OdbcDataType,
         source: odbc_api::Error,
     },
+    /// We are getting a display size from ODBC but it is not larger than 0.
     #[error("ODBC reported a display size of {0}.")]
     InvalidDisplaySize(isize),
+    /// Failure to retrieve the number of columns from the result set.
     #[error("Unable to retrieve number of columns in result set.\n{0}")]
     UnableToRetrieveNumCols(odbc_api::Error),
 }
@@ -170,17 +178,25 @@ impl<C: Cursor> OdbcReader<C> {
                         ArrowDataType::Float64
                     }
                     OdbcDataType::Date => ArrowDataType::Date32,
-                    OdbcDataType::Timestamp { precision: 0 } => ArrowDataType::Timestamp(TimeUnit::Second ,None),
+                    OdbcDataType::Timestamp { precision: 0 } => {
+                        ArrowDataType::Timestamp(TimeUnit::Second, None)
+                    }
                     OdbcDataType::Timestamp { precision: 1..=3 } => {
                         ArrowDataType::Timestamp(TimeUnit::Millisecond, None)
                     }
-                    OdbcDataType::Timestamp { precision: 4..=6 } => ArrowDataType::Timestamp(TimeUnit::Microsecond, None),
-                    OdbcDataType::Timestamp { precision: _ } => ArrowDataType::Timestamp(TimeUnit::Nanosecond, None),
+                    OdbcDataType::Timestamp { precision: 4..=6 } => {
+                        ArrowDataType::Timestamp(TimeUnit::Microsecond, None)
+                    }
+                    OdbcDataType::Timestamp { precision: _ } => {
+                        ArrowDataType::Timestamp(TimeUnit::Nanosecond, None)
+                    }
                     OdbcDataType::BigInt => ArrowDataType::Int64,
                     OdbcDataType::TinyInt => ArrowDataType::Int8,
                     OdbcDataType::Bit => ArrowDataType::Boolean,
+                    OdbcDataType::Binary { length } => {
+                        ArrowDataType::FixedSizeBinary(length.try_into().unwrap())
+                    }
                     OdbcDataType::LongVarbinary { length: _ }
-                    | OdbcDataType::Binary { length: _ }
                     | OdbcDataType::Varbinary { length: _ } => ArrowDataType::Binary,
                     OdbcDataType::Unknown
                     | OdbcDataType::Time { precision: _ }
@@ -364,6 +380,10 @@ fn choose_column_strategy(
         ArrowDataType::Timestamp(TimeUnit::Nanosecond, _) => {
             with_conversion(field.is_nullable(), TimestampNsConversion)
         }
+        ArrowDataType::FixedSizeBinary(length) => Box::new(FixedSizedBinary::new(
+            field.is_nullable(),
+            (*length).try_into().unwrap(),
+        )),
         arrow_type
         @
         (ArrowDataType::Null
@@ -372,7 +392,6 @@ fn choose_column_strategy(
         | ArrowDataType::Time64(_)
         | ArrowDataType::Duration(_)
         | ArrowDataType::Interval(_)
-        | ArrowDataType::FixedSizeBinary(_)
         | ArrowDataType::LargeBinary
         | ArrowDataType::LargeUtf8
         | ArrowDataType::List(_)
