@@ -1,7 +1,8 @@
 use std::sync::Arc;
 
-use arrow::{array::{Array, ArrayRef, BinaryArray, BooleanArray, Date32Array, DecimalArray, Float32Array, Int16Array, Int32Array, Int64Array, Int8Array, StringArray, TimestampMillisecondArray, TimestampNanosecondArray, UInt8Array}, datatypes::{DataType, Field, Schema}};
+use arrow::{array::{Array, ArrayRef, BinaryArray, BooleanArray, Date32Array, DecimalArray, FixedSizeBinaryArray, Float32Array, Int16Array, Int32Array, Int64Array, Int8Array, StringArray, TimestampMillisecondArray, TimestampNanosecondArray, UInt8Array}, datatypes::{DataType, Field, Schema}};
 use chrono::NaiveDate;
+use float_eq::assert_float_eq;
 use lazy_static::lazy_static;
 
 use arrow_odbc::{
@@ -162,9 +163,9 @@ fn fetch_boolean() {
     let array_vals = array_any.as_any().downcast_ref::<BooleanArray>().unwrap();
 
     // Assert that the correct values are found within the arrow batch
-    assert_eq!(true, array_vals.value(0));
-    assert_eq!(false, array_vals.value(1));
-    assert_eq!(true, array_vals.value(2));
+    assert!(array_vals.value(0));
+    assert!(!array_vals.value(1));
+    assert!(array_vals.value(2));
 }
 
 /// Fill a record batch with nullable Booleans from Bits
@@ -178,10 +179,10 @@ fn fetch_nullable_boolean() {
 
     // Assert that the correct values are found within the arrow batch
     assert!(array_vals.is_valid(0));
-    assert_eq!(true, array_vals.value(0));
+    assert!(array_vals.value(0));
     assert!(array_vals.is_null(1));
     assert!(array_vals.is_valid(2));
-    assert_eq!(false, array_vals.value(2));
+    assert!(!array_vals.value(2));
 }
 
 /// Fill a record batch with non nullable `f32` directly from the datasource
@@ -192,7 +193,7 @@ fn fetch_32bit_floating_point() {
     let array_any = fetch_arrow_data(table_name, "REAL NOT NULL", "(1),(2),(3)").unwrap();
 
     let array_vals = array_any.as_any().downcast_ref::<Float32Array>().unwrap();
-    assert_eq!([1., 2., 3.], array_vals.values());
+    assert_float_eq!(&[1., 2., 3.][..], array_vals.values(), abs_all <= 000.1);
 }
 
 /// Fill a record batch with non nullable `f64` directly from the datasource
@@ -206,7 +207,7 @@ fn fetch_64bit_floating_point() {
     let array_vals = array_any.as_any().downcast_ref::<Float64Array>().unwrap();
 
     // Assert that the correct values are found within the arrow batch
-    assert_eq!([1., 2., 3.], array_vals.values());
+    assert_float_eq!(&[1., 2., 3.][..], array_vals.values(), abs_all <= 000.1);
 }
 
 /// Fill a record batch with non nullable `i64` directly from the datasource
@@ -266,12 +267,12 @@ fn fetch_dates() {
 
     // Assert that the correct values are found within the arrow batch
     assert_eq!(
-        Some(NaiveDate::from_ymd(2021, 04, 09)),
+        Some(NaiveDate::from_ymd(2021, 4, 9)),
         array_vals.value_as_date(0)
     );
     assert!(array_vals.is_null(1));
     assert_eq!(
-        Some(NaiveDate::from_ymd(2002, 09, 30)),
+        Some(NaiveDate::from_ymd(2002, 9, 30)),
         array_vals.value_as_date(2)
     );
 }
@@ -288,11 +289,11 @@ fn fetch_non_null_dates() {
 
     // Assert that the correct values are found within the arrow batch
     assert_eq!(
-        Some(NaiveDate::from_ymd(2021, 04, 09)),
+        Some(NaiveDate::from_ymd(2021, 4, 9)),
         array_vals.value_as_date(0)
     );
     assert_eq!(
-        Some(NaiveDate::from_ymd(2002, 09, 30)),
+        Some(NaiveDate::from_ymd(2002, 9, 30)),
         array_vals.value_as_date(1)
     );
 }
@@ -316,11 +317,11 @@ fn fetch_non_null_date_time() {
 
     // Assert that the correct values are found within the arrow batch
     assert_eq!(
-        Some(NaiveDate::from_ymd(2021, 04, 09).and_hms_milli(18, 57, 50, 120)),
+        Some(NaiveDate::from_ymd(2021, 4, 9).and_hms_milli(18, 57, 50, 120)),
         array_vals.value_as_datetime(0)
     );
     assert_eq!(
-        Some(NaiveDate::from_ymd(2002, 09, 30).and_hms_milli(12, 43, 17, 450)),
+        Some(NaiveDate::from_ymd(2002, 9, 30).and_hms_milli(12, 43, 17, 450)),
         array_vals.value_as_datetime(1)
     );
 }
@@ -344,12 +345,12 @@ fn fetch_date_time() {
 
     // Assert that the correct values are found within the arrow batch
     assert_eq!(
-        Some(NaiveDate::from_ymd(2021, 04, 09).and_hms_milli(18, 57, 50, 0)),
+        Some(NaiveDate::from_ymd(2021, 4, 9).and_hms_milli(18, 57, 50, 0)),
         array_vals.value_as_datetime(0)
     );
     assert!(array_vals.is_null(1));
     assert_eq!(
-        Some(NaiveDate::from_ymd(2002, 09, 30).and_hms_milli(12, 43, 17, 00)),
+        Some(NaiveDate::from_ymd(2002, 9, 30).and_hms_milli(12, 43, 17, 00)),
         array_vals.value_as_datetime(2)
     );
 }
@@ -373,11 +374,11 @@ fn fetch_non_null_date_time_2() {
 
     // Assert that the correct values are found within the arrow batch
     assert_eq!(
-        Some(NaiveDate::from_ymd(2021, 04, 09).and_hms_nano(18, 57, 50, 123_456_700)),
+        Some(NaiveDate::from_ymd(2021, 4, 9).and_hms_nano(18, 57, 50, 123_456_700)),
         array_vals.value_as_datetime(0)
     );
     assert_eq!(
-        Some(NaiveDate::from_ymd(2002, 09, 30).and_hms_nano(12, 43, 17, 456_000_000)),
+        Some(NaiveDate::from_ymd(2002, 9, 30).and_hms_nano(12, 43, 17, 456_000_000)),
         array_vals.value_as_datetime(1)
     );
 }
@@ -397,13 +398,12 @@ fn fetch_decimals() {
     assert_eq!("678.90", array_vals.value_as_string(1));
 }
 
-/// Fetch binary data
-/// Like [`fetch_32bit_floating_point`], but utilizing a prepared query instead of a one shot.
+/// Fetch variable sized binary data binary data
 #[test]
 fn fetch_varbinary_data() {
     let table_name = function_name!().rsplit_once(':').unwrap().1;
 
-    // Setup a table on the database with some floats (so we can fetch them)
+    // Setup a table on the database with some values (so we can fetch them)
     let conn = ENV.connect_with_connection_string(MSSQL).unwrap();
     setup_empty_table(&conn, table_name, &["VARBINARY(30) NOT NULL"]).unwrap();
     let sql = format!("INSERT INTO {} (a) VALUES (?)", table_name);
@@ -438,6 +438,46 @@ fn fetch_varbinary_data() {
     assert_eq!(b"World", array_vals.value(1));
 }
 
+/// Fetch fixed sized binary data binary data
+#[test]
+fn fetch_fixed_sized_binary_data() {
+    let table_name = function_name!().rsplit_once(':').unwrap().1;
+
+    // Setup a table on the database with some values (so we can fetch them)
+    let conn = ENV.connect_with_connection_string(MSSQL).unwrap();
+    setup_empty_table(&conn, table_name, &["BINARY(5) NOT NULL"]).unwrap();
+    let sql = format!("INSERT INTO {} (a) VALUES (?)", table_name);
+    // Use prepared query and arguments for insertion, since literal representation depends a lot
+    // on the DB under test.
+    let mut insert = conn.prepare(&sql).unwrap();
+    insert.execute(&b"Hello".into_parameter()).unwrap();
+    insert.execute(&b"World".into_parameter()).unwrap();
+
+    // Query column with values to get a cursor
+    let sql = format!("SELECT a FROM {} ORDER BY id", table_name);
+    let cursor = conn.execute(&sql, ()).unwrap().unwrap();
+
+    // Now that we have a cursor, we want to iterate over its rows and fill an arrow batch with it.
+
+    // Batches will contain at most 100 entries.
+    let max_batch_size = 100;
+
+    // Instantiate reader with Arrow schema and ODBC cursor
+    let mut reader = OdbcReader::new(cursor, max_batch_size).unwrap();
+
+    // Batch for batch copy values from ODBC buffer into arrow batches
+    let arrow_batch = reader.next().unwrap().unwrap();
+
+    // Assert that the correct values are found within the arrow batch
+    let array_vals = arrow_batch
+        .column(0)
+        .as_any()
+        .downcast_ref::<FixedSizeBinaryArray>()
+        .unwrap();
+    assert_eq!(b"Hello", array_vals.value(0));
+    assert_eq!(b"World", array_vals.value(1));
+}
+
 /// Like [`fetch_32bit_floating_point`], but utilizing a prepared query instead of a one shot.
 #[test]
 fn prepared_query() {
@@ -471,7 +511,7 @@ fn prepared_query() {
         .as_any()
         .downcast_ref::<Float32Array>()
         .unwrap();
-    assert_eq!([1., 2., 3.], array_vals.values());
+    assert_float_eq!(&[1., 2., 3.][..], array_vals.values(), abs_all <= 000.1);
 }
 
 /// Inserts the values in the literal into the database and returns them as an Arrow array.
